@@ -52,21 +52,22 @@ def get_game_logs(_name, start_date, end_date, playoffs=False):
         selector = 'div_pgl_basic'
     final_df = None
     for year in years:
-        r = get(f'https://widgets.sports-reference.com/wg.fcgi?css=1&site=bbr&url={suffix}%2Fgamelog%2F{year}&div={selector}')
+        r = get(f'https://widgets.sports-reference.com/wg.fcgi?css=1&site=bbr&url={suffix}%2Fgamelog%2F{year}%2F&div={selector}')
         if r.status_code==200:
             soup = BeautifulSoup(r.content, 'html.parser')
             table = soup.find('table')
             if table:
                 df = pd.read_html(str(table))[0]
                 df.rename(columns = {'Date': 'DATE', 'Age': 'AGE', 'Tm': 'TEAM', 'Unnamed: 5': 'HOME/AWAY', 'Opp': 'OPPONENT',
-                        'Unnamed: 7': 'RESULT', 'GmSc': 'GAME_SCORE'}, inplace=True)
+                    'Unnamed: 7': 'RESULT', 'GmSc': 'GAME_SCORE'}, inplace=True)
                 df['HOME/AWAY'] = df['HOME/AWAY'].apply(lambda x: 'AWAY' if x=='@' else 'HOME')
                 df = df[df['Rk']!='Rk']
                 df = df.drop(['Rk', 'G'], axis=1)
-                df = df.loc[(df['DATE'] >= start_date_str) & (df['DATE'] <= end_date_str)]
+                df['DATE'] = pd.to_datetime(df['DATE'])
+                df = df.loc[(df['DATE'] >= start_date) & (df['DATE'] <= end_date)]
                 active_df = pd.DataFrame(columns = list(df.columns))
                 for index, row in df.iterrows():
-                    if row['GS']!='1':
+                    if row['GS']!=1 and row['GS']!='1':
                         continue
                     active_df = active_df.append(row)
                 if final_df is None:
